==> gworkspace-0.8.2.tar.gz: GWorkspace-0.8.2/Inspector/IconView.h <==
/* IconView.m
 *  
 * Copyright (C) 2005 Free Software Foundation, Inc.
 *
 * Author: Enrico Sersale <enrico@imago.ro>
 * Date: August 2005
 *
 * This file is part of the GNUstep GWorkspace application
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
 */

#ifndef ICON_VIEW_H
#define ICON_VIEW_H

#include <Foundation/Foundation.h>
#include <AppKit/NSImageView.h>

@interface IconView : NSImageView
{
  id inspector;
  BOOL dndTarget;
}

- (void)setInspector:(id)insp;

- (void)setDndTarget:(BOOL)value;

@end


@interface IconView (NSDraggingDestination)

- (unsigned int)draggingEntered:(id <NSDraggingInfo>)sender;

- (unsigned int)draggingUpdated:(id <NSDraggingInfo>)sender;

- (void)draggingExited:(id <NSDraggingInfo>)sender;

- (BOOL)prepareForDragOperation:(id <NSDraggingInfo>)sender;

- (BOOL)performDragOperation:(id <NSDraggingInfo>)sender;

- (void)concludeDragOperation:(id <NSDraggingInfo>)sender;

- (unsigned int)draggingSourceOperationMaskForLocal:(BOOL)isLocal;

@end

#endif // TIMEDATEVIEW_H

==> gworkspace_0.8.3.orig.tar.gz: GWorkspace-0.8.3/Inspector/IconView.h <==
/* IconView.m
 *  
 * Copyright (C) 2005 Free Software Foundation, Inc.
 *
 * Author: Enrico Sersale <enrico@imago.ro>
 * Date: August 2005
 *
 * This file is part of the GNUstep GWorkspace application
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
 */

#ifndef ICON_VIEW_H
#define ICON_VIEW_H

#include <Foundation/Foundation.h>
#include <AppKit/NSImageView.h>

@interface IconView : NSImageView
{
  id inspector;
  BOOL dndTarget;
}

- (void)setInspector:(id)insp;

- (void)setDndTarget:(BOOL)value;

@end


@interface IconView (NSDraggingDestination)

- (NSDragOperation)draggingEntered:(id <NSDraggingInfo>)sender;

- (NSDragOperation)draggingUpdated:(id <NSDraggingInfo>)sender;

- (void)draggingExited:(id <NSDraggingInfo>)sender;

- (BOOL)prepareForDragOperation:(id <NSDraggingInfo>)sender;

- (BOOL)performDragOperation:(id <NSDraggingInfo>)sender;

- (void)concludeDragOperation:(id <NSDraggingInfo>)sender;

- (unsigned int)draggingSourceOperationMaskForLocal:(BOOL)isLocal;

@end

#endif // TIMEDATEVIEW_H
